#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_cybak-lzma
----------------------------------

Tests for `cybak-lzma` module.
"""

import unittest

from cybak-lzma import cybak-lzma


class TestCybak-lzma(unittest.TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass

if __name__ == '__main__':
    unittest.main()
